@@ -23,7 +23,7 @@ options(width = 80)
 summary(lm1)
 
 ## ---- echo = F, fig.width = 8, fig.height = 2---------------------------------
-par(mfrow = c(1, 3), mgp = c(1, 0.6, 0), mar = c(2.5, 1, 2, 1))
+op <- par(mfrow = c(1, 3), mgp = c(1, 0.6, 0), mar = c(2.5, 1, 2, 1))
 mus <- c(1, -1.5, -2.5)
 
 for (i in seq_along(mus)) {
@@ -45,6 +45,7 @@ for (i in seq_along(mus)) {
   axis(side = 1, at = 0)
   abline(v = 0, lty = 2)
 }
+par(op)
 
 ## ---- fig.width = 8, fig.height = 5-------------------------------------------
 densplot(lm1)
